/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2010, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.threads.metadata;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;

@XmlType(name = "bounded-queue-thread-pool-executor", propOrder = {})
public final class BoundedQueueThreadPoolExecutorMetaData {
    private String name;
    private boolean allowCoreTimeout;
    private boolean blocking;
    private ScaledCountMetaData coreThreads;
    private ScaledCountMetaData queueLength;
    private ScaledCountMetaData maxThreads;
    private TimeMetaData keepaliveTime;
    private TaskFilterMetaData taskFilter;
    private RefMetaData threadFactory;
    private RefMetaData handoffExecutor;

    public String getName() {
        return name;
    }

    @XmlAttribute(required = true)
    public void setName(final String name) {
        this.name = name;
    }

    public boolean isAllowCoreTimeout() {
        return allowCoreTimeout;
    }

    @XmlAttribute
    public void setAllowCoreTimeout(final boolean allowCoreTimeout) {
        this.allowCoreTimeout = allowCoreTimeout;
    }

    public boolean isBlocking() {
        return blocking;
    }

    @XmlAttribute
    public void setBlocking(final boolean blocking) {
        this.blocking = blocking;
    }

    public ScaledCountMetaData getCoreThreads() {
        return coreThreads;
    }

    @XmlElement(name = "core-threads")
    public void setCoreThreads(final ScaledCountMetaData coreThreads) {
        this.coreThreads = coreThreads;
    }

    public ScaledCountMetaData getQueueLength() {
        return queueLength;
    }

    @XmlElement(name = "queue-length", required = true)
    public void setQueueLength(final ScaledCountMetaData queueLength) {
        this.queueLength = queueLength;
    }

    public ScaledCountMetaData getMaxThreads() {
        return maxThreads;
    }

    @XmlElement(name = "max-threads", required = true)
    public void setMaxThreads(final ScaledCountMetaData maxThreads) {
        this.maxThreads = maxThreads;
    }

    public TimeMetaData getKeepaliveTime() {
        return keepaliveTime;
    }

    @XmlElement(name = "keepalive-time")
    public void setKeepaliveTime(final TimeMetaData keepaliveTime) {
        this.keepaliveTime = keepaliveTime;
    }

    public TaskFilterMetaData getTaskFilter() {
        return taskFilter;
    }

    @XmlElement(name = "task-filter")
    public void setTaskFilter(final TaskFilterMetaData taskFilter) {
        this.taskFilter = taskFilter;
    }

    public RefMetaData getThreadFactory() {
        return threadFactory;
    }

    @XmlElement(name = "thread-factory")
    public void setThreadFactory(final RefMetaData threadFactory) {
        this.threadFactory = threadFactory;
    }

    public RefMetaData getHandoffExecutor() {
        return handoffExecutor;
    }

    @XmlElement(name = "handoff-executor")
    public void setHandoffExecutor(final RefMetaData handoffExecutor) {
        this.handoffExecutor = handoffExecutor;
    }
}
